clear
set more off
set mem 100m
*generating 01_EXPFOOD.dta
cd "C:\Africa\Ghana\GLSS4-1998"
*---------------------------------------------
use "02_CLEANDATA\SEC9B", clear
des
*total observations 167,803
*---------------------------------------------
*HID
egen HID= concat( clust nh), p(/)
*---------------------------------------------
*generating the total amount of expenditure during the 7 survey visits
egen amt = rowtotal(s9bq1 s9bq2 s9bq3 s9bq4 s9bq5 s9bq6)
*---------------------------------------------
tab fdexpcd, miss
/* Food item codes have values from 1 to 125.
The food item codes are not labeled in the data file and DO NOT correspond 
fully with the accompanying codebook and the questionnaire. 
The codebook has codes until 83 and the questionnaire until 107.
Items coded from 1 to 107 account for 81.39% of the total observations. 
18.61% of the observations are miscoded.
In view of the above it is assumed that all the balance codes (108 to 125)refer to food 
and NOT to beverages (alcoholic and non-alcohlic) or tobacco.*/
*---------------------------------------------
/*Annualizing the value
The survey captures expenditure over a 36 day period
7 visits at 5 day intervals=7*5=35 days
The 36th day is used for travelling.
For annualizing multiply the expenditure by (365/36)*/
gen az_amt=amt*(365/35)
*---------------------------------------------
*FD_B
gen FD_B = az_amt if (fdexpcd>=1 & fdexpcd<=97)|(fdexpcd>=108 & fdexpcd<=125)
*---------------------------------------------
*FDNONALC_B 
gen FDNONALC_B = az_amt if fdexpcd==98
*---------------------------------------------
collapse (sum)FD_B FDNONALC_B, by (HID)
sort HID
des
*total observations 5,998
save 04_AGGDATA\EXPFOOD, replace
*----------------------------------------------------
use "02_CLEANDATA\SEC8H", clear
des
*number of observations 44,603
*----------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
*unique hid values 4,098
*----------------------------------------------------
tab  homagrcd, miss
*The item codes are consistently coded.
*----------------------------------------------------
*generating the total number of units consumed during the 7 survey visits
egen qty= rowtotal(s8hq3 s8hq4 s8hq5 s8hq6 s8hq7 s8hq8)
gen amt1=qty*s8hq10
*----------------------------------------------------
/*Annualizing the value
The survey captures expenditure over a 36 day period
7 visits at 5 day intervals=7*5=35 days
The 36th day is used for travelling.*/
tab s8hq1, m
*CHECK: Consistently coded; no missing values
tab s8hq2, m
*CHECK: Consistently coded; no missing values,
tab s8hq2 s8hq1, m
/* 1. 2 observations had meaningful values for s8hq2, but coded as 'No' in s8hq1.
These 2 observations have been recoded as 0 in s8hq2.*/
replace s8hq2=0 if (s8hq2!=0 & s8hq1==2)
*For annualizing multiply the expenditure by (number of months*30/36)
gen az_amt1=amt1*(s8hq2*30)/35
*s8hq2 is the number of months the produce was consumed
*----------------------------------------------------
*FD_P
gen FD_P = az_amt1 if (homagrcd>=1 & homagrcd<=71) 
*----------------------------------------------------
*FDNONALC_P
gen FDNONALC_P = az_amt1 if homagrcd==91
*----------------------------------------------------
collapse (sum)FD_P FDNONALC_P, by (HID)
sort HID
des
*number of observations 4,098
*------------------------------------------------------
merge HID using 04_AGGDATA\EXPFOOD
tab _merge
*3=4098; 2=1900
drop _merge
sort HID
*------------------------------------------------------
*FDRECALL
gen FDRECALL=5/7
*7 visits at 5 day intervals
*------------------------------------------------------
*TOTFOOD
egen TOTFOOD =rowtotal(FD_B FDNONALC_B FD_P FDNONALC_P)
*------------------------------------------------------
*labeling the variables
label var HID "Household unique ID"
label var FD_B "Total expenditure on purchased food excluding beverages, tobacco, catering and restaurant foods"
label var FDNONALC_B "Total expenditure on purchased non-alcoholic beverages"
label var FD_P "Total value of foods other than purchased"
label var FDNONALC_P "Total value of nonalcoholic beverages other than purchased"
label var TOTFOOD "Total food expenditure, sum of variables prefixed fd"
label var FDRECALL "Recall period in weeks"
*------------------------------------------------------
order HID FDRECALL FD_B FDNONALC_B FD_P FDNONALC_P TOTFOOD
keep HID FDRECALL FD_B FDNONALC_B FD_P FDNONALC_P TOTFOOD
des
*number of observations 5,998
sort HID
save 04_AGGDATA\01_EXPFOOD, replace
erase 04_AGGDATA\EXPFOOD.dta
