clear
set more off
set mem 100m
*generating 02_EXPALCH.dta
cd "C:\Africa\Ghana\GLSS4-1998"
*---------------------------------------------
use "02_CLEANDATA\SEC9B", clear
des
*total observations 167,803
*---------------------------------------------
*HID
egen HID= concat( clust nh), p(/)
*---------------------------------------------
*dropping the observations that do not relate to alcoholic beverages and tobacco
keep if fdexpcd>=99 & fdexpcd<=107
*number of observations 6,433
*---------------------------------------------
*generating the total amount of expenditure during the 7 survey visits
egen amt = rowtotal(s9bq1 s9bq2 s9bq3 s9bq4 s9bq5 s9bq6)
*---------------------------------------------
/*Annualizing the value
The survey captures expenditure over a 36 day period
7 visits at 5 day intervals=7*5=35 days
The 36th day is used for travelling.
For annualizing multiply the expenditure by (365/35)*/
gen az_amt=amt*(365/35)
*---------------------------------------------
*FDALC_B
gen FDALC_B = az_amt if (fdexpcd>=99 & fdexpcd<=104)
*---------------------------------------------
*TOBACCO
gen TOBACCO = az_amt if (fdexpcd>=105 & fdexpcd<=107)
*---------------------------------------------
collapse (sum)FDALC_B TOBACCO, by (HID)
sort HID
des
*total observations 3,746
save 04_AGGDATA\EXPALCH, replace
*----------------------------------------------------
use "02_CLEANDATA\SEC8H", clear
des
*number of observations 44,603
*----------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
*unique hid values 4,098
*----------------------------------------------------
tab  homagrcd, miss
*The item codes are consistently coded.
*---------------------------------------------
*dropping the observations that do not relate to alcoholic beverages and tobacco
keep if homagrcd==90
*number of observations 188
*----------------------------------------------------
*generating the total number of units consumed during the 7 survey visits
egen qty= rowtotal(s8hq3 s8hq4 s8hq5 s8hq6 s8hq7 s8hq8)
gen amt1=qty*s8hq10
*----------------------------------------------------
/*Annualizing the value
The survey captures expenditure over a 35 day period
7 visits at 5 day intervals=7*5=35 days
The 36th day is used for travelling.*/
tab s8hq1, m
*CHECK: Consistently coded; no missing values
tab s8hq2, m
*CHECK: Consistently coded; no missing values,
tab s8hq2 s8hq1, m
/* 1. No observations had meaningful values for s8hq2, but coded as 'No' in s8hq1.
For annualizing multiply the expenditure by (number of months*30/35)*/
gen az_amt1=amt1*(s8hq2*30)/35
*s8hq2 is the number of months the produce was consumed
*----------------------------------------------------
*FDALC_P
gen FDALC_P = az_amt1 
collapse (sum)FDALC_P, by (HID)
sort HID
des
*number of observations 188
*------------------------------------------------------
merge HID using 04_AGGDATA\EXPALCH
tab _merge
*3=166; 1=22; 2=3580
/*CHECK - THE ABOVE INDICATES THAT 22 HOUSEHOLDS ONLY CONSUME SELF-PRODUCED ALCOHOL.
THEY AND DO NOT PURCHASE IT.*/
drop _merge
sort HID
*------------------------------------------------------
*NARCOTICS
gen NARCOTICS=.
*No data on narcotics
*------------------------------------------------------
*TOTALCH
egen TOTALCH =rowtotal(FDALC_B FDALC_P TOBACCO NARCOTICS)
*------------------------------------------------------
*labeling the variables
label var FDALC_B "Total expenditure on purchased alcoholic beverages"
label var FDALC_P "Total value of alcoholic beverages other than purchased"
label var TOBACCO "Total (expenditure on/value of)(tobacco/tobacco products)(purchased/received/produced)"
label var NARCOTICS "Total (expenditure on/value of)(narcotics/narcotics products)(purchased/received/produced)"
label var TOTALCH "Total expenditure on alcoholic beverages, tobacco, and narcotics)"
*------------------------------------------------------
order HID FDALC_B FDALC_P TOBACCO NARCOTICS TOTALCH 
keep HID FDALC_B FDALC_P TOBACCO NARCOTICS TOTALCH
des
*number of observations 3,768
sort HID
save 04_AGGDATA\02_EXPALCH, replace
erase 04_AGGDATA\EXPALCH.dta
