clear
set more off
set mem 100m
*generating 03_EXPCLTH.dta
cd "C:\Africa\Ghana\GLSS4-1998"
*---------------------------------------------
/*Non-food expenditure is classified as FREQUENT and LESS-FREQUENT.
FREQUENT is captured in SEC9A2.
LESS-FREQUENT is captured in SEC9A12.
The item codes are designed to be mutually exclusive in both these sections in the codebook.
It needs to be checked if they are consistently coded in the dataset.*/
*---------------------------------------------
use "02_CLEANDATA\SEC9A2", clear
des
*Number of observations 65,222
*---------------------------------------------
egen HID= concat( clust nh), p(/)
codebook HID
*number of households 5,995
*---------------------------------------------
*Checking the item codes
tab nfdex2cd, miss
*Consistently coded
*---------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex2cd>=214 & nfdex2cd<=220)
des
*number of observations 4,611
*---------------------------------------------
*generating the total amount of expenditure during the 7 survey visits
egen amt = rowtotal(s9a2q1 s9a2q2 s9a2q3 s9a2q4 s9a2q5 s9a2q6)
*---------------------------------------------
/*Annualizing the value
The survey captures expenditure over a 36 day period
7 visits at 5 day intervals=7*5=35 days
The 36th day is used for travelling.
For annualizing multiply the expenditure by (365/35)*/
gen az_amt=amt*(365/35)
*---------------------------------------------
*hscloth_9A2
gen hscloth_9A2 = az_amt if nfdex2cd==214
*---------------------------------------------
*hsfootw_9A2
gen hsfootw_9A2 = az_amt if nfdex2cd==220
*---------------------------------------------
collapse (sum)hscloth_9A2 hsfootw_9A2, by (HID)
sort HID
des
*total observations 3,301
save 04_AGGDATA\EXPCLTH, replace
*----------------------------------------------------
use "02_CLEANDATA\SEC9A12", clear
des
*number of observations 84,286
*----------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*unique hid values 5,973
*----------------------------------------------------
tab  nfdex1cd, miss
*The item codes are consistently coded.
*----------------------------------------------------
*Expenditure is recorded either on an annual basis or on a quarterly basis
tab s9a1q3 s9a1q4 if (s9a1q3!=. & s9a1q4!=.)
/*8 observations have non-missing values for both s9a1q3 and s9a1q4. Of these:-
(a) 4 observations have meaningful values for s9a1q3 but corresponding value for s9a1q4 is 0.
(b) 2 observations have meaningful values for s9a1q4 but corresponding value for s9a1q3 is 0.
These codes have been left unchanged since they will not affect aggregation.
(c)2 observations have meaningful values for s9a1q4 but corresponding value for s9a1q3 is non-zero, but not meaningful(very low almost negligible values).
For these 2 observations the value of s9a1q3 have been recoded to 0*/
replace s9a1q3=0 if (s9a1q3!=. & s9a1q4!=.) & (s9a1q3!=0 & s9a1q4!=0)
*----------------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex1cd>=201 & nfdex1cd<=219)
des
*number of observations 45,194
*----------------------------------------------------
/*Annualizing the value
The survey captures expenditure over either an annual or a quarterly period.
Quarterly expenditure is multiplied by 4*/
gen amt= s9a1q4 * 4
egen az_amt= rowtotal(s9a1q3 amt)
*----------------------------------------------------
*hscloth_9A12
gen hscloth_9A12 = az_amt if (nfdex1cd>=201 & nfdex1cd<=213)
*----------------------------------------------------
*hsfootw_9A12
gen hsfootw_9A12 = az_amt if (nfdex1cd>=215 & nfdex1cd<=219)
*----------------------------------------------------
collapse (sum)hscloth_9A12 hsfootw_9A12, by (HID)
sort HID
des
*number of observations 5,915
*------------------------------------------------------
merge HID using 04_AGGDATA\EXPCLTH
tab _merge
*3=3271; 1=2644; 2=30
*CHECK- 30 households only repaired old clothes and shoes; did not purchase new ones. 
drop _merge
sort HID
*------------------------------------------------------
*HSCLOTH
egen HSCLOTH=rowtotal(hscloth_9A2 hscloth_9A12)
*------------------------------------------------------
*HSFOOTW
egen HSFOOTW=rowtotal(hsfootw_9A2 hsfootw_9A12)
*------------------------------------------------------
*TOTCLTH
egen TOTCLTH =rowtotal(HSCLOTH HSFOOTW)
*------------------------------------------------------
*labeling the variables
label var HID "Household unique ID"
label var HSCLOTH "Total expenditure on clothing and its repair including gifted/self-produced"
label var HSFOOTW "Total expenditure on footware and its repair including gifted/self-produced"
label var TOTCLTH "Total expenditure on clothing and footware"
*------------------------------------------------------
order HID HSCLOTH HSFOOTW TOTCLTH
keep HID HSCLOTH HSFOOTW TOTCLTH
des
*number of observations 5,945
sort HID
save 04_AGGDATA\03_EXPCLTH, replace
erase 04_AGGDATA\EXPCLTH.dta
