clear
set more off
set mem 100m
*generating 04_EXPHOUS.dta
cd "C:\Africa\Ghana\GLSS4-1998"
*---------------------------------------------
/*Non-food expenditure is classified as FREQUENT and LESS-FREQUENT.
FREQUENT is captured in SEC9A2.
LESS-FREQUENT is captured in SEC9A12.
The item codes are designed to be mutually exclusive in both these sections in the codebook.
It needs to be checked if they are consistently coded in the dataset.*/
*---------------------------------------------
use "02_CLEANDATA\SEC9A2", clear
des
*Number of observations 65,222
*---------------------------------------------
egen HID= concat( clust nh), p(/)
codebook HID
*number of households 5,995
*---------------------------------------------
*Checking the item codes
tab nfdex2cd, miss
*Consistently coded
*---------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex2cd>=308 & nfdex2cd<=313)
des
*number of observations 10,993
*---------------------------------------------
*generating the total amount of expenditure during the 7 survey visits
egen amt = rowtotal(s9a2q1 s9a2q2 s9a2q3 s9a2q4 s9a2q5 s9a2q6)
*---------------------------------------------
/*Annualizing the value
The survey captures expenditure over a 36 day period
7 visits at 5 day intervals=7*5=35 days
The 36th day is used for travelling.
For annualizing multiply the expenditure by (365/35)*/
gen az_amt=amt*(365/35)
*---------------------------------------------
*hswater_9A2
gen hswater_9A2 = az_amt if nfdex2cd==308
*---------------------------------------------
*GAS
gen GAS = az_amt if nfdex2cd==310
*---------------------------------------------
*ELEC
gen ELEC = .
*---------------------------------------------
*HSFUEL
gen HSFUEL= az_amt if (nfdex2cd>=312 & nfdex2cd<=313)
*---------------------------------------------
*HSKEROSENE
gen HSKEROSENE= az_amt if nfdex2cd==311
*---------------------------------------------
*HSDIESEL
gen HSDIESEL= .
*---------------------------------------------
*HSUTILITY
egen HSUTILITY = rowtotal(GAS ELEC)
*---------------------------------------------
collapse (sum)hswater_9A2 GAS ELEC HSUTILITY HSKEROSENE HSDIESEL HSFUEL, by (HID)
sort HID
des
*total observations 5,790
save 04_AGGDATA\EXPHOUS, replace
*----------------------------------------------------
use "02_CLEANDATA\SEC9A12", clear
des
*number of observations 84,286
*----------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*unique hid values 5,973
*----------------------------------------------------
tab  nfdex1cd, miss
*The item codes are consistently coded.
*----------------------------------------------------
*Expenditure is recorded either on an annual basis or on a quarterly basis
tab s9a1q3 s9a1q4 if (s9a1q3!=. & s9a1q4!=.)
/*8 observations have non-missing values for both s9a1q3 and s9a1q4. Of these:-
(a) 4 observations have meaningful values for s9a1q3 but corresponding value for s9a1q4 is 0.
(b) 2 observations have meaningful values for s9a1q4 but corresponding value for s9a1q3 is 0.
These codes have been left unchanged since they will not affect aggregation.
(c)2 observations have meaningful values for s9a1q4 but corresponding value for s9a1q3 is non-zero, but not meaningful(very low almost negligible values).
For these 2 observations the value of s9a1q3 have been recoded to 0*/
replace s9a1q3=0 if (s9a1q3!=. & s9a1q4!=.) & (s9a1q3!=0 & s9a1q4!=0)
*----------------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex1cd>=303 & nfdex1cd<=307)
des
*number of observations 2,573
*----------------------------------------------------
/*Annualizing the value
The survey captures expenditure over either an annual or a quarterly period.
Quarterly expenditure is multiplied by 4*/
gen amt= s9a1q4 * 4
egen az_amt= rowtotal(s9a1q3 amt)
*----------------------------------------------------
*RENT_ACT
gen RENT_ACT = az_amt if (nfdex1cd>=303 & nfdex1cd<=304)
*----------------------------------------------------
*hswater_9A12
gen hswater_9A12 = az_amt if nfdex1cd==307
*----------------------------------------------------
collapse (sum)RENT_ACT hswater_9A12, by (HID)
sort HID
des
*number of observations 2,258
*------------------------------------------------------
merge HID using 04_AGGDATA\EXPHOUS
tab _merge
*3=2200; 1=58; 2=3590
drop _merge
sort HID
*------------------------------------------------------
*HSWATER
egen HSWATER=rowtotal(hswater_9A2 hswater_9A12)
*------------------------------------------------------
*RENT_IMP
gen RENT_IMP=.
*------------------------------------------------------
*HSREPAIR
gen HSREPAIR=.
*------------------------------------------------------
*TOTHOUS
egen TOTHOUS =rowtotal(HSREPAIR HSWATER HSUTILITY HSKEROSENE HSDIESEL HSFUEL)
*Does not include RENT_ACT and RENT_IMP
*------------------------------------------------------
*labeling the variables
label var HID "Household unique ID"
label var RENT_ACT "Actual rentals for housing"
label var RENT_IMP "Imputed rentals for housing - SAME AS OWNER OCCUPIED HOUSING RENT"
label var HSREPAIR "Expenditure on maintenance and repair of dwelling"
label var HSWATER "Expenditure on water supply and miscellaneous services related to dwelling"
label var HSFUEL "Expenditure on firewood charcoal and other fuel"
label var GAS "Expenditure on cooking gas"
label var ELEC "Expenditure on electricity"
label var HSKEROSENE "Expenditure on kerosene"
label var HSDIESEL "Expenditure on diesel for non-transportation purposes"
label var HSUTILITY "Expenditure on electricity and gas"
label var TOTHOUS "Total expenditure on housing"
*------------------------------------------------------
order HID RENT_ACT RENT_IMP HSREPAIR HSWATER HSFUEL GAS ELEC HSKEROSENE HSDIESEL HSUTILITY TOTHOUS
keep HID RENT_ACT RENT_IMP HSREPAIR HSWATER HSFUEL GAS ELEC HSKEROSENE HSDIESEL HSUTILITY TOTHOUS
des
*number of observations 5,848
sort HID
save 04_AGGDATA\04_EXPHOUS,replace
erase 04_AGGDATA\EXPHOUS.dta
