clear
set more off
set mem 100m
*generating 05_EXPFURN.dta
cd "C:\Africa\Ghana\GLSS4-1998"
*---------------------------------------------
/*Non-food expenditure is classified as FREQUENT and LESS-FREQUENT.
FREQUENT is captured in SEC9A2.
LESS-FREQUENT is captured in SEC9A12.
The item codes are designed to be mutually exclusive in both these sections in the codebook.
It needs to be checked if they are consistently coded in the dataset.*/
*---------------------------------------------
use "02_CLEANDATA\SEC9A2", clear
des
*Number of observations 65,222
*---------------------------------------------
egen HID= concat( clust nh), p(/)
codebook HID
*number of households 5,995
*---------------------------------------------
*Checking the item codes
tab nfdex2cd, miss
*Consistently coded
*---------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex2cd>=404 & nfdex2cd<=433)
des
*number of observations 16,720
*---------------------------------------------
*generating the total amount of expenditure during the 7 survey visits
egen amt = rowtotal(s9a2q1 s9a2q2 s9a2q3 s9a2q4 s9a2q5 s9a2q6)
*---------------------------------------------
/*Annualizing the value
The survey captures expenditure over a 36 day period
7 visits at 5 day intervals=7*5=35 days
The 36th day is used for travelling.
For annualizing multiply the expenditure by (365/35)*/
gen az_amt=amt*(365/35)
*---------------------------------------------
*hsfurni_9A2
gen hsfurni_9A2 = az_amt if (nfdex2cd>=404 & nfdex2cd<=410)
*---------------------------------------------
*hsapplian_9A2
gen hsapplian_9A2 = az_amt if nfdex2cd==420
*---------------------------------------------
*hsserv_9A2
gen hsserv_9A2 = az_amt if (nfdex2cd>=425 & nfdex2cd<=433)
*---------------------------------------------
collapse (sum)hsfurni_9A2 hsapplian_9A2 hsserv_9A2, by (HID)
sort HID
des
*total observations 5,936
save 04_AGGDATA\EXPFURN, replace
*----------------------------------------------------
use "02_CLEANDATA\SEC9A12", clear
des
*number of observations 84,286
*----------------------------------------------------
tab  nfdex1cd, miss
*The item codes are consistently coded.
*----------------------------------------------------
*Expenditure is recorded either on an annual basis or on a quarterly basis
tab s9a1q3 s9a1q4 if (s9a1q3!=. & s9a1q4!=.)
/*8 observations have non-missing values for both s9a1q3 and s9a1q4. Of these:-
(a) 4 observations have meaningful values for s9a1q3 but corresponding value for s9a1q4 is 0.
(b) 2 observations have meaningful values for s9a1q4 but corresponding value for s9a1q3 is 0.
These codes have been left unchanged since they will not affect aggregation.
(c)2 observations have meaningful values for s9a1q4 but corresponding value for s9a1q3 is non-zero, but not meaningful(very low almost negligible values).
For these 2 observations the value of s9a1q3 have been recoded to 0*/
replace s9a1q3=0 if (s9a1q3!=. & s9a1q4!=.) & (s9a1q3!=0 & s9a1q4!=0)
*----------------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex1cd>=401 & nfdex1cd<=432)
des
*number of observations 19,016
*----------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*unique hid values 5,123
*----------------------------------------------------
/*Annualizing the value
The survey captures expenditure over either an annual or a quarterly period.
Quarterly expenditure is multiplied by 4*/
gen amt= s9a1q4 * 4
egen az_amt= rowtotal(s9a1q3 amt)
*----------------------------------------------------
*hsfurni_9A12
gen hsfurni_9A12 = az_amt if (nfdex1cd>=405 & nfdex1cd<=409)
*----------------------------------------------------
*HSTEXTIL
gen HSTEXTIL = az_amt if (nfdex1cd>=401 & nfdex1cd<=403)
*----------------------------------------------------
*hsapplian_9A12
gen hsapplian_9A12 = az_amt if (nfdex1cd>=411 & nfdex1cd<=419)
*----------------------------------------------------
*HSUTENSIL
gen HSUTENSIL = az_amt if (nfdex1cd>=421 & nfdex1cd<=424)
*----------------------------------------------------
*hsserv_9A12
gen hsserv_9A12 = az_amt if nfdex1cd==432
*----------------------------------------------------
collapse (sum)hsfurni_9A12 HSTEXTIL hsapplian_9A12 HSUTENSIL hsserv_9A12, by (HID)
sort HID
des
*number of observations 5,123
*------------------------------------------------------
merge HID using 04_AGGDATA\EXPFURN
tab _merge
*3=5088; 1=35; 2=848
drop _merge
sort HID
*------------------------------------------------------
*HSFURNI
egen HSFURNI=rowtotal(hsfurni_9A2 hsfurni_9A12)
*------------------------------------------------------
*HSAPPLIAN
egen HSAPPLIAN=rowtotal(hsapplian_9A2 hsapplian_9A12)
*------------------------------------------------------
*HSTOOLS
gen HSTOOLS=.
*------------------------------------------------------
*HSSERV
egen HSSERV=rowtotal(hsserv_9A2 hsserv_9A12)
*------------------------------------------------------
*TOTFURN
egen TOTFURN =rowtotal(HSFURNI HSTEXTIL HSAPPLIAN HSUTENSIL HSTOOLS HSSERV)
*------------------------------------------------------
*labeling the variables
label var HID "Household unique ID"
label var HSFURNI "Expenditure on furniture and furnishings"
label var HSTEXTIL "Expenditure on household textiles"
label var HSAPPLIAN "Expenditure on household appliances"
label var HSUTENSIL "Expenditure on glassware, tableware, kitchenware, and household utensils"
label var HSTOOLS "Expenditure on household and garden tools and equipment" 
label var HSSERV "Expenditure on goods of routine household maintenance"
label var TOTFURN "Total expenditure on furnishings"
*------------------------------------------------------
order HID HSFURNI HSTEXTIL HSAPPLIAN HSUTENSIL HSTOOLS HSSERV TOTFURN
keep HID HSFURNI HSTEXTIL HSAPPLIAN HSUTENSIL HSTOOLS HSSERV TOTFURN
des
*number of observations 5,971
sort HID
save 04_AGGDATA\05_EXPFURN, replace
erase 04_AGGDATA\EXPFURN.dta
