clear
set more off
set mem 100m
*generating 06_EXPHLTH.dta
cd "C:\Africa\Ghana\GLSS4-1998"
*---------------------------------------------
/*Non-food expenditure is classified as FREQUENT and LESS-FREQUENT.
FREQUENT is captured in SEC9A2.
LESS-FREQUENT is captured in SEC9A12.
The item codes are designed to be mutually exclusive in both these sections in the codebook.
It needs to be checked if they are consistently coded in the dataset.*/
*---------------------------------------------
use "02_CLEANDATA\SEC9A2", clear
des
*Number of observations 65,222
*---------------------------------------------
*Checking the item codes
tab nfdex2cd, miss
*Consistently coded
*---------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex2cd>=501 & nfdex2cd<=513)
des
*number of observations 11,146
*---------------------------------------------
egen HID= concat( clust nh), p(/)
codebook HID
*number of households 5,347
*---------------------------------------------
*generating the total amount of expenditure during the 7 survey visits
egen amt = rowtotal(s9a2q1 s9a2q2 s9a2q3 s9a2q4 s9a2q5 s9a2q6)
*---------------------------------------------
/*Annualizing the value
The survey captures expenditure over a 36 day period
7 visits at 5 day intervals=7*5=35 days
The 36th day is used for travelling.
For annualizing multiply the expenditure by (365/36)*/
gen az_amt=amt*(365/36)
*---------------------------------------------
*hlmedi_9A2
gen hlmedi_9A2 = az_amt if nfdex2cd>=501 & nfdex2cd<=504
*---------------------------------------------
*hloutp_9A2
gen hloutp_9A2 = az_amt if nfdex2cd==513
*---------------------------------------------
collapse (sum)hlmedi_9A2 hloutp_9A2, by (HID)
sort HID
des
*total observations 5,347
save 04_AGGDATA\EXPHLTH, replace
*----------------------------------------------------
use "02_CLEANDATA\SEC9A12", clear
des
*number of observations 84,286
*----------------------------------------------------
tab  nfdex1cd, miss
*The item codes are consistently coded.
*----------------------------------------------------
*Expenditure is recorded either on an annual basis or on a quarterly basis
tab s9a1q3 s9a1q4 if (s9a1q3!=. & s9a1q4!=.)
/*8 observations have non-missing values for both s9a1q3 and s9a1q4. Of these:-
(a) 4 observations have meaningful values for s9a1q3 but corresponding value for s9a1q4 is 0.
(b) 2 observations have meaningful values for s9a1q4 but corresponding value for s9a1q3 is 0.
These codes have been left unchanged since they will not affect aggregation.
(c)2 observations have meaningful values for s9a1q4 but corresponding value for s9a1q3 is non-zero, but not meaningful(very low almost negligible values).
For these 2 observations the value of s9a1q3 have been recoded to 0*/
replace s9a1q3=0 if (s9a1q3!=. & s9a1q4!=.) & (s9a1q3!=0 & s9a1q4!=0)
*----------------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex1cd>=505 & nfdex1cd<=512)
des
*number of observations 8,653
*----------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*unique hid values 4,854
*----------------------------------------------------
/*Annualizing the value
The survey captures expenditure over either an annual or a quarterly period.
Quarterly expenditure is multiplied by 4*/
gen amt= s9a1q4 * 4
egen az_amt= rowtotal(s9a1q3 amt)
*----------------------------------------------------
*hlmedi_9A12
gen hlmedi_9A12 = az_amt if nfdex1cd==505
*----------------------------------------------------
*hloutp_9A12
gen hloutp_9A12 = az_amt if (nfdex1cd>=506 & nfdex1cd<=510)
*----------------------------------------------------
*HOSP
gen HOSP = az_amt if nfdex1cd==511
*----------------------------------------------------
collapse (sum)hlmedi_9A12 hloutp_9A12 HOSP, by (HID)
sort HID
des
*number of observations 4,854
*------------------------------------------------------
merge HID using 04_AGGDATA\EXPHLTH
tab _merge
*3= 4392; 1=462; 2=955
drop _merge
sort HID
*------------------------------------------------------
*HLMEDI
egen HLMEDI=rowtotal(hlmedi_9A2 hlmedi_9A12)
*------------------------------------------------------
*HLOUTP
egen HLOUTP=rowtotal(hloutp_9A2 hloutp_9A12)
*------------------------------------------------------
*TOTHLTH
egen TOTHLTH =rowtotal(HLMEDI HLOUTP)
*------------------------------------------------------
*labeling the variables
label var HID "Household unique ID"
label var HLMEDI "Expenditure on medical products, appliances and equipment"
label var HLOUTP "Expenditure on outpatient services"
label var HOSP "Expenditure on hospital services i.e hospitalization"
label var TOTHLTH "Total expenditure on health"
*------------------------------------------------------
order HID HLMEDI HLOUTP HOSP TOTHLTH
keep HID HLMEDI HLOUTP HOSP TOTHLTH
des
*number of observations 5,809
sort HID
save 04_AGGDATA\06_EXPHLTH, replace
erase 04_AGGDATA\EXPHLTH.dta
