clear
set more off
set mem 100m
*generating 07_EXPTRSP.dta
cd "C:\Africa\Ghana\GLSS4-1998"
*---------------------------------------------
/*Non-food expenditure is classified as FREQUENT and LESS-FREQUENT.
FREQUENT is captured in SEC9A2.
LESS-FREQUENT is captured in SEC9A12.
The item codes are designed to be mutually exclusive in both these sections in the codebook.
It needs to be checked if they are consistently coded in the dataset.*/
*---------------------------------------------
use "02_CLEANDATA\SEC9A2", clear
des
*Number of observations 65,222
*---------------------------------------------
*Checking the item codes
tab nfdex2cd, miss
*Consistently coded
*---------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex2cd>=605 & nfdex2cd<=612)
des
*number of observations 5,552
*---------------------------------------------
egen HID= concat( clust nh), p(/)
codebook HID
*number of households 4,496
*---------------------------------------------
*generating the total amount of expenditure during the 7 survey visits
egen amt = rowtotal(s9a2q1 s9a2q2 s9a2q3 s9a2q4 s9a2q5 s9a2q6)
*---------------------------------------------
/*Annualizing the value
The survey captures expenditure over a 36 day period
7 visits at 5 day intervals=7*5=35 days
The 36th day is used for travelling.
For annualizing multiply the expenditure by (365/36)*/
gen az_amt=amt*(365/36)
*---------------------------------------------
*trperson_9A2
gen trperson_9A2 = az_amt if (nfdex2cd==605|nfdex2cd==609)
*---------------------------------------------
*TRFUEL
gen TRFUEL = az_amt if nfdex2cd==608
*---------------------------------------------
*TRSERVE
gen TRSERVE = az_amt if nfdex2cd>=610 & nfdex2cd<=612
*---------------------------------------------
collapse (sum)trperson_9A2 TRFUEL TRSERVE, by (HID)
sort HID
des
*total observations 4,496
save 04_AGGDATA\EXPTRSP, replace
*----------------------------------------------------
use "02_CLEANDATA\SEC9A12", clear
des
*number of observations 84,286
*----------------------------------------------------
tab  nfdex1cd, miss
*The item codes are consistently coded.
*----------------------------------------------------
*Expenditure is recorded either on an annual basis or on a quarterly basis
tab s9a1q3 s9a1q4 if (s9a1q3!=. & s9a1q4!=.)
/*8 observations have non-missing values for both s9a1q3 and s9a1q4. Of these:-
(a) 4 observations have meaningful values for s9a1q3 but corresponding value for s9a1q4 is 0.
(b) 2 observations have meaningful values for s9a1q4 but corresponding value for s9a1q3 is 0.
These codes have been left unchanged since they will not affect aggregation.
(c)2 observations have meaningful values for s9a1q4 but corresponding value for s9a1q3 is non-zero, but not meaningful(very low almost negligible values).
For these 2 observations the value of s9a1q3 have been recoded to 0*/
replace s9a1q3=0 if (s9a1q3!=. & s9a1q4!=.) & (s9a1q3!=0 & s9a1q4!=0)
*----------------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex1cd>=601 & nfdex1cd<=604)
des
*number of observations 995
*----------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*unique hid values 789
*----------------------------------------------------
/*Annualizing the value
The survey captures expenditure over either an annual or a quarterly period.
Quarterly expenditure is multiplied by 4*/
gen amt= s9a1q4 * 4
egen az_amt= rowtotal(s9a1q3 amt)
*----------------------------------------------------
*VEHICLES
gen VEHICLES = az_amt if (nfdex1cd>=601 & nfdex1cd<=603)
*BICYCLES have been included in VEHICLES
*----------------------------------------------------
*trperson_9A12
gen trperson_9A12 = az_amt if nfdex1cd==604
*----------------------------------------------------
collapse (sum)VEHICLES trperson_9A12, by (HID)
sort HID
des
*number of observations 789
*------------------------------------------------------
merge HID using 04_AGGDATA\EXPTRSP
tab _merge
*3= 536; 1=253; 2=3960
drop _merge
sort HID
*------------------------------------------------------
*TRPERSON
egen TRPERSON=rowtotal(trperson_9A2 trperson_9A12)
*------------------------------------------------------
*TOTTRSP
egen TOTTRSP =rowtotal(TRFUEL TRPERSON TRSERVE)
*------------------------------------------------------
*labeling the variables
label var HID "Household unique ID"
label var VEHICLES "Purchase of vehicles"
label var TRPERSON "Expenditure on personal transport equipment/repairs/chauffeurs etc."
label var TRFUEL "Transportation fuel"
label var TRSERVE "Expenditure on public transportation/airfare etc."
label var TOTTRSP "Total expenditure on transport"
*------------------------------------------------------
order HID VEHICLES TRFUEL TRPERSON TRSERVE TOTTRSP
keep HID VEHICLES TRFUEL TRPERSON TRSERVE TOTTRSP
des
*number of observations 4,749
sort HID
save 04_AGGDATA\07_EXPTRSP, replace
erase 04_AGGDATA\EXPTRSP.dta
