clear
set more off
set mem 100m
*generating 10_GHA_EXPEDUC.dta
cd "C:\Africa\Ghana\GLSS4-1998"
*---------------------------------------------
/*Non-food expenditure is classified as FREQUENT and LESS-FREQUENT.
FREQUENT is captured in SEC9A2.
LESS-FREQUENT is captured in SEC9A12.
The item codes are designed to be mutually exclusive in both these sections in the codebook.
It needs to be checked if they are consistently coded in the dataset.*/
*---------------------------------------------
use "02_CLEANDATA\SEC9A2", clear
des
*Number of observations 65,222
*---------------------------------------------
*Checking the item codes
tab nfdex2cd, miss
*Consistently coded
*---------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if nfdex2cd==718
des
*number of observations 2,647
*---------------------------------------------
egen HID= concat( clust nh), p(/)
codebook HID
*number of households 2,647
*---------------------------------------------
*generating the total amount of expenditure during the 7 survey visits
egen amt = rowtotal(s9a2q1 s9a2q2 s9a2q3 s9a2q4 s9a2q5 s9a2q6)
*---------------------------------------------
/*Annualizing the value
The survey captures expenditure over a 36 day period
7 visits at 5 day intervals=7*5=35 days
The 36th day is used for travelling.
For annualizing multiply the expenditure by (365/36)*/
gen az_amt=amt*(365/36)
*---------------------------------------------
*EDUNDEFIN
gen EDUNDEFIN = az_amt
*---------------------------------------------
collapse (sum)EDUNDEFIN, by (HID)
sort HID
des
*total observations 2,647
*---------------------------------------------
*EDPRIMAR
gen EDPRIMAR = .
*---------------------------------------------
*EDSECOND
gen EDSECOND = .
*---------------------------------------------
*EDPOSTSEC
gen EDPOSTSEC = .
*---------------------------------------------
*EDTERTIAR
gen EDTERTIAR = .
*---------------------------------------------
*TOTEDUC
egen TOTEDUC =rowtotal(EDPRIMAR EDSECOND EDPOSTSEC EDTERTIAR EDUNDEFIN)
*------------------------------------------------------
*labeling the variables
label var HID "Household unique ID"
label var EDPRIMAR "Expenditure on pre-primary and primary education"
label var EDSECOND "Expenditure on secondary education"
label var EDPOSTSEC "Expenditure on post-secondary but non-tertiary education"
label var EDTERTIAR "Expenditure on tertiary education"
label var EDUNDEFIN "Expenditure on education cannot be defined"
label var TOTEDUC "Total expenditure on education"
*------------------------------------------------------
order HID EDPRIMAR EDSECOND EDPOSTSEC EDTERTIAR EDUNDEFIN TOTEDUC 
keep HID EDPRIMAR EDSECOND EDPOSTSEC EDTERTIAR EDUNDEFIN TOTEDUC
des
*number of observations 2,647
sort HID
save 04_AGGDATA\10_EXPEDUC, replace
