clear
set more off
set mem 100m
*generating 12_EXPMISC.dta
cd "C:\Africa\Ghana\GLSS4-1998"
*---------------------------------------------
/*Non-food expenditure is classified as FREQUENT and LESS-FREQUENT.
FREQUENT is captured in SEC9A2.
LESS-FREQUENT is captured in SEC9A12.
The item codes are designed to be mutually exclusive in both these sections in the codebook.
It needs to be checked if they are consistently coded in the dataset.*/
*---------------------------------------------
use "02_CLEANDATA\SEC9A2", clear
des
*Number of observations 65,222
*---------------------------------------------
*Checking the item codes
tab nfdex2cd, miss
*Consistently coded
*---------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex2cd>=801 & nfdex2cd<=808)
drop if (nfdex2cd==805|nfdex2cd==806)
des
*number of observations 9,350
*---------------------------------------------
egen HID= concat( clust nh), p(/)
codebook HID
*number of households 5,242
*---------------------------------------------
*generating the total amount of expenditure during the 7 survey visits
egen amt = rowtotal(s9a2q1 s9a2q2 s9a2q3 s9a2q4 s9a2q5 s9a2q6)
*---------------------------------------------
/*Annualizing the value
The survey captures expenditure over a 36 day period
7 visits at 5 day intervals=7*5=35 days
The 36th day is used for travelling.
For annualizing multiply the expenditure by (365/36)*/
gen az_amt=amt*(365/36)
*---------------------------------------------
*MISPERSN
gen MISPERSN = az_amt if (nfdex2cd>=801 & nfdex2cd<=802)
*---------------------------------------------
*MISFINAN
gen MISFINAN = az_amt if nfdex2cd==807
*---------------------------------------------
*MISOTHER
gen MISOTHER = az_amt if nfdex2cd==808
*---------------------------------------------
collapse (sum)MISPERSN MISFINAN MISOTHER, by (HID)
sort HID
des
*total observations 5,242
save 04_AGGDATA\EXPMISC, replace
*----------------------------------------------------
use "02_CLEANDATA\SEC9A12", clear
des
*number of observations 84,286
*----------------------------------------------------
tab  nfdex1cd, miss
*The item codes are consistently coded.
*----------------------------------------------------
*Expenditure is recorded either on an annual basis or on a quarterly basis
tab s9a1q3 s9a1q4 if (s9a1q3!=. & s9a1q4!=.)
/*8 observations have non-missing values for both s9a1q3 and s9a1q4. Of these:-
(a) 4 observations have meaningful values for s9a1q3 but corresponding value for s9a1q4 is 0.
(b) 2 observations have meaningful values for s9a1q4 but corresponding value for s9a1q3 is 0.
These codes have been left unchanged since they will not affect aggregation.
(c)2 observations have meaningful values for s9a1q4 but corresponding value for s9a1q3 is non-zero, but not meaningful(very low almost negligible values).
For these 2 observations the value of s9a1q3 have been recoded to 0*/
replace s9a1q3=0 if (s9a1q3!=. & s9a1q4!=.) & (s9a1q3!=0 & s9a1q4!=0)
*----------------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex1cd>=803 & nfdex1cd<=804)
des
*number of observations 6,643
*----------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*unique hid values 4301
*----------------------------------------------------
/*Annualizing the value
The survey captures expenditure over either an annual or a quarterly period.
Quarterly expenditure is multiplied by 4*/
gen amt= s9a1q4 * 4
egen az_amt= rowtotal(s9a1q3 amt)
*----------------------------------------------------
*MISPEREFF
gen MISPEREFF = az_amt 
*----------------------------------------------------
collapse (sum)MISPEREFF, by (HID)
sort HID
des
*number of observations 4,301
*------------------------------------------------------
merge HID using 04_AGGDATA\EXPMISC
tab _merge
*3= 3,908; 1=393; 2=1,334
drop _merge
sort HID
*----------------------------------------------------
*MISPROST
gen MISPROST = . 
*----------------------------------------------------
*MISSPROT
gen MISSPROT = . 
*----------------------------------------------------
*MISINSUR
gen MISINSUR = . 
*------------------------------------------------------
*TOTMISC
egen TOTMISC =rowtotal(MISPERSN MISPROST MISPEREFF MISSPROT MISINSUR MISFINAN MISOTHER)
*------------------------------------------------------
*labeling the variables
label var HID "Household unique ID"
label var MISPERSN "Total expenditure on personal care"
label var MISPROST "Expenditure on prostitution"
label var MISPEREFF "Expenditure on personal effects not mentioned elsewhere"
label var MISSPROT "Expenditure on social protection"
label var MISINSUR "Expenditure on insurance, including housing,health etc."
label var MISFINAN "Expenditure on fianancial services"
label var MISOTHER" Total expenditure on other services not mentioned elsewhere"
label var TOTMISC "Total miscelleneous expenditure"
*------------------------------------------------------
order HID MISPERSN MISPROST MISPEREFF MISSPROT MISINSUR MISFINAN MISOTHER TOTMISC
keep HID MISPERSN MISPROST MISPEREFF MISSPROT MISINSUR MISFINAN MISOTHER TOTMISC
des
*number of observations 5,635
sort HID
save 04_AGGDATA\12_EXPMISC, replace
erase 04_AGGDATA\EXPMISC.dta
