clear
clear matrix
set more off
set mem 100m
*generating GHA_1998_I.dta
cd "C:\Africa\Ghana\GLSS4-1998"
*---------------------------------------------
use "04_AGGDATA\00_BASICINFO",clear
sort HID
save "04_AGGDATA\GHA_I",replace
*---------------------------------------------
use "02_CLEANDATA\SEC0A.dta", clear
des
*number of observations 5,988
*---------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*5,998 unique values generated
*---------------------------------------------
sort HID
merge HID using 04_AGGDATA\GHA_I
tab _merge
/*CHECK: Correctly merged
3=5,998*/
drop _merge
*number of observations 
*---------------------------------------------
*PROVINCE
gen PROVINCE=.
*no data
*---------------------------------------------
*DISTRICT
tab district, miss
*CHECK: Consistently coded; No missing values
gen DISTRICT=district
*---------------------------------------------
sort HID
save 04_AGGDATA\GHA_I, replace
*---------------------------------------------
use"02_CLEANDATA\SEC1", clear
des
*Number of observations 26,411
*---------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*5,998 unique values generated
*---------------------------------------------
sort HID
merge HID using 04_AGGDATA\GHA_I
tab _merge
/*CHECK: Correctly merged
3=26,411*/
drop _merge
*---------------------------------------------
*INDID
egen INDID = concat(pid)
*---------------------------------------------
*SEX
tab sex, miss
*CHECK: Consistently coded; No missing values
recode sex (2=0),gen(SEX)
tab sex SEX, miss
*---------------------------------------------
*RELAT
tab  rel, miss
*CHECK: Consistently coded; No missing values
recode  rel (1=1)(2=2)(3=3)(4=5)(5=4)(6=7)(7 8 9=9), gen (RELAT)
*no observations coded as 6 "son/daughter in law" since the data does not allow it.
tab SEX RELAT, miss
/*CHECK: Consistently coded; No missing values;
There are 5,998 head of household of which 2,017 are female.
There are 3,375 spouses of which 144 are male*/
*---------------------------------------------
*HEAD
gen HEAD = 0
replace HEAD = 1 if RELAT==1
tab HEAD, miss
/*CHECK: Consistently coded - number of heads is equal to the number of households (5998);
No missing values.*/
*---------------------------------------------
*SP_PRES
tab s1q7, miss
/*CHECK: In-consistently coded-since spouse present is more than those reported as spouse;
18,434 missing values - */ 
recode s1q7 (2=0) if RELAT==2, gen (SP_PRES)
tab SP_PRES, miss
/*CHECK: Consistently coded - SP_PRES generated only for individuals reported as spouse;
 23,049 missing values.*/
*---------------------------------------------
*AGEY
tab agey, miss
/*CHECK: Consistently coded- 20 observations coded as 99;
No missing values.*/
gen AGEY = agey
replace AGEY=98 if (AGEY>=99 & AGEY!=.)
*---------------------------------------------
*AGEM
*This information is captured only for children below 5 yrs old in the survey
count if agem!=.
*4019 observations
count if agey<=5
*4148 observations
*There are 129 individuals who are more than 5 years old and less than 6 years old
/*CHECK: Inconsitently coded-differences in 129 observations. 
No changes made since it is more likely that AGEY was recorded incorrectly in the survey.*/
gen AGEM = agem
*---------------------------------------------
*ETHNICITY
tab s1q12, miss
/*CHECK: Consistently coded; No missing values.*/
gen ETHNICITY=s1q12
*---------------------------------------------
*LANGUAGE
gen LANGUAGE=.
*no data
*---------------------------------------------
*RELIGION
tab s1q9, miss
/*CHECK: Consistently coded; No missing values.*/
gen RELIGION = s1q9
*---------------------------------------------
*MARSTAT
*Marital status is coded only for individuals more than 15 years old
tab mar, miss
/*CHECK: Consistently coded; 11,388 missing values*/
tab agey if mar==., miss
*CHECK: Consistently coded - All 11,388 missing observations are aged below 15yrs.
recode mar (1=2)(2=4)(3=5)(4=6)(5=1), gen (MARSTAT)
*Married individuals (2) need to be further classified as monogamous or polygamous
/*CHECK - checking for consistency between MARSTAT and RELAT*/
tab MARSTAT RELAT, miss
/* CHECK - Inconsistent coding
8 individuals reported never married and spouse.
4 individuals reported divorced/separated and spouse.
1 individuals reported widowed and spouse.
The marital status of the above individuals is recoded to 2'married monogamous*/
replace MARSTAT=2 if (MARSTAT==1|MARSTAT==5|MARSTAT==6) & RELAT==2 
/*CHECK - checking for polygamy/polyandry*/
bysort HID:egen spouses=count(RELAT) if RELAT==2
/*This generates number of spouses only for individuals that reported to be spouses
Replacing this value for household heads as well.*/
bysort HID:egen polygamy=mean(spouses) if (RELAT==1|RELAT==2) 
tab polygamy, miss
*CHECK - Consistently coded*
replace MARSTAT=3 if (polygamy>1 & polygamy!=.)&(RELAT==1|RELAT==2)
tab MARSTAT RELAT, miss
/*CHECK - Consistently coded - 169 polygamous households*/
/*CHECK - Checking SP_PRES against MARSTAT*/
tab SP_PRES MARSTAT, miss
/*CHECK - Consistently coded - Only married individuals (MARSTAT-2/3/4) have spouses present.*/
*---------------------------------------------
sort HID INDID
save 04_AGGDATA\GHA_I, replace
*-------------------------------------------------
use "02_CLEANDATA\SEC2A",clear
des
*number of observations 22,211
*-------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
/*number of households 5,997. 
Information for 1 household is not available in the dataset.*/
*-------------------------------------------------
*INDID
egen INDID = concat(pid)
*-------------------------------------------------
*EVERATTD
tab s2aq1, miss
/*CHECK: Consistently coded-5,269 individual never attended school; 
No missing observations*/
recode s2aq1 (2=0) ,gen (EVERATTD)
*-------------------------------------------------
*ATSCHOOL
tab s2aq4, miss
/*CHECK: Consistently coded; 
5,629 missing values for individual who never attended school.*/
recode s2aq4 (1=1)(2=0), gen(ATSCHOOL)
tab ATSCHOOL EVERATTD, m
replace ATSCHOOL=0 if ATSCHOOL==. & EVERATTD!=.
*Replacing EVERATTD as yes if ATSCHOOL is yes
replace EVERATTD=1 if EVERATTD==0 & ATSCHOOL==1
*-------------------------------------------------
*EDLEVEL_AR
tab s2aq2, miss
/*CHECK: Consistently coded; 
5,629 missing values for individual who never attended school.*/
recode s2aq2 (1=0)(2=1)(3=2)(4 5 8 9=3) ///
	(6 7 10=4)(11 12 13 14 15 =5)(16=6) ///
	(17 96=9), gen (EDLEVEL_AR)
*Koranic education is classified as 9 "other"
replace EDLEVEL_AR=0 if EVERATTD==0
tab EDLEVEL_AR s2aq2, miss
/*CHECK: Consistently coded; 
5,269 missing values for individual who never attended school.*/
tab EDLEVEL_AR EVERATTD, miss
*CHECK: Consistently coded
*Nothing is coded as 1'pre-school'or 8'literacy program'
*-------------------------------------------------
*EDYEARS_AT
gen EDYEARS_AT=.
*-------------------------------------------------
*EDYEARS
gen EDYEARS=.
*-------------------------------------------------
*SCHLTYP
gen SCHLTYP=.
*no data
*-------------------------------------------------
sort HID INDID
merge HID INDID using 04_AGGDATA\GHA_I
tab _merge
drop _merge
*-------------------------------------------------
sort HID INDID
des
*number of observations 
save 04_AGGDATA\GHA_I, replace
*--------------------------------------
use "02_CLEANDATA\SEC2B", clear
des
/*Number of observations 11,939
Individual level file for individuals aged 15yrs or more
Contains information regarding vocational training*/ 
*-------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*number of households 5,035
*-------------------------------------------------
*INDID
egen INDID = concat(pid)
*-------------------------------------------------
tab s2bq8, miss
/*CHECK: Consistently coded- No individual has a docterate certificate;
11,760 missing values*/
*-------------------------------------------------
sort HID INDID
merge HID INDID using 04_AGGDATA\GHA_I
tab _merge
/*CHECK: Correctly merged
2= 14,472
3= 11,939*/
drop _merge
*-------------------------------------------------
*EDYEARS
*Since current grade is not available EDYEARS is based on highest qualification attained 
replace EDYEARS=20 if s2bq8==4
replace EDYEARS=22 if s2bq8==5
/*EDYEARS is coded for Masters degree and Docterate degrees.
CHECK: Checking EDYEARS and EDLEVEL_AR*/
tab EDLEVEL_AR EDYEARS, miss
/*CHECK: Consistently coded- No individual has a docterate certificate;
4,359 missing values for EDLEVEL_AR coded as 9 and for children aged 5yrs and less*/
*-------------------------------------------------
sort HID INDID
des
*number of observations 26,411
save 04_AGGDATA\GHA_I, replace
*-------------------------------------------------
use "02_CLEANDATA\SEC2C", clear
des
/*Number of observations 5,988
Individual level file for individuals aged 15yrs or more
Contains information regarding literacy and apprenticeship*/ 
*-------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
*-------------------------------------------------
*INDID
egen INDID = concat(pid)
*-------------------------------------------------
tab s2cq1, miss
*CHECK: Consistently coded; no missing values
tab s2cq1, miss
*CHECK: Consistently coded; no missing values
tab s2cq1, miss
*CHECK: Consistently coded; no missing values
*-------------------------------------------------
sort HID INDID
merge HID INDID using 04_AGGDATA\GHA_I
tab _merge
/*CHECK: Correctly merged
2= 4,157
3= 22,254*/
drop _merge
*-------------------------------------------------
*LITERACY
gen LITERACY =1 if s2cq1==1|s2cq2!=1|s2cq3==1|s2cq4!=1
replace LITERACY = 2 if (s2cq1==2 & s2cq3==2) & (s2cq2==1 & s2cq4==1)
replace LITERACY = 1 if (EDLEVEL_AR>=3 & EDLEVEL_AR<=9)
/*Individuals have been considered literate if they have responded	that they
can eihter read or write or have completed primary education and above or 'other' education/literacy program*/
tab LITERACY AGEY if AGEY<=5, miss
*CHECK: Inconsistent coding.
replace LITERACY = . if AGEY<=5
*LITERACY for children aged 5 years or less have been recoded as missing
*No observations have been coded as 3
*-------------------------------------------------
sort HID INDID
save 04_AGGDATA\GHA_I, replace
*-------------------------------------------------
use "02_CLEANDATA\SEC3A", clear
des
/*Number of observations 25,581
Individual level file
Contains information regarding health*/ 
*-------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*number of households 5,998
*-------------------------------------------------
*INDID
egen INDID = concat(pid)
*-------------------------------------------------
sort HID INDID
merge HID INDID using 04_AGGDATA\GHA_I
tab _merge
/*CHECK: Correctly merged
2= 830
3= 25,581*/
drop _merge
*-------------------------------------------------
*MORB_TR
gen MORB_TR= 2
*-------------------------------------------------
*MORBID
tab s3aq1, miss
*CHECK: Consistently coded; 830 missing values due to merging.
recode s3aq1 (2 3 4= 1)(1=0),gen (MORBID)
*-------------------------------------------------
*RTREATM
tab s3aq5, miss
*CHECK: Consistently coded; 830 missing values due to merging.
recode s3aq5 (1=1)(2=0),gen (RTREATM)
*-------------------------------------------------
*HLTHFAC
tab s3aq8 if RTREATM==1, miss
*CHECK: Consistently coded; No missing values if the individual sought medical attention.
tab s3aq6 if RTREATM==1, miss
*CHECK: Consistently coded; No missing values if the individual sought medical attention.
recode s3aq8 (1=1)(4=2)(2 5 6=3)(3=5)(9=9), gen (HLTHFAC)
replace HLTHFAC=6 if (s3aq6==1|s3aq6==9)
replace HLTHFAC=9 if s3aq6==8
tab s3aq8 HLTHFAC if RTREATM==1, miss
*CHECK: Consistently coded; No missing values if the individual sought medical attention.
*CHECK - LOGIC HAS GAPS
*-------------------------------------------------
*OWHPROVD
tab s3aq9, miss
*CHECK
tab s3aq6, miss
*CHECK
recode s3aq9 (1=1)(2=2), gen(OWHPROVD)
replace OWHPROVD=3 if RTREATM==1 & s3aq6==1
replace OWHPROVD=4 if RTREATM==1 & s3aq6==9
replace OWHPROVD=9 if RTREATM==1 & (OWHPROVD!=1 & s3aq6==10)
*-------------------------------------------------
sort HID INDID
save 04_AGGDATA\GHA_I, replace
*-------------------------------------------------
use "02_CLEANDATA\SEC3B", clear
des
/*Number of observations 5,658
Individual level file for individuals aged below 7 yrs 
Contains information regarding vaccination*/ 
*-------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
*-------------------------------------------------
*INDID
egen INDID = concat(pid)
*-------------------------------------------------
sort HID INDID
merge HID INDID using 04_AGGDATA\GHA_I
tab _merge
drop _merge
*-------------------------------------------------
*keeping observations only for children below 5 years of age
keep if AGEM<=60
des
*number of observations 4019
*-------------------------------------------------
*WHDELIV
gen WHDELIV=.
*no data
*-------------------------------------------------
*VCARD
gen VCARD=.
*no data
*-------------------------------------------------
*BCG
tab s3bq2bcg, miss
*CHECK
recode s3bq2bcg (1=1)(2 4=0)(3=9), gen (BCG)
*not applicable (4) have been recoded as "no" since 4 is defined as underage for vaccination 
*-------------------------------------------------
*POLIO_DO
gen pdoses=0
tab s3bq2po1, miss
*CHECK
replace pdoses=pdoses+1 if s3bq2po1==1
tab s3bq2po2, miss
*CHECK
replace pdoses=pdoses+1 if s3bq2po2==1
tab s3bq2po3, miss
*CHECK
replace pdoses=pdoses+1 if s3bq2po3==1
gen POLIO_DO = pdoses
replace POLIO_DO=9 if (s3bq2po1==3 & s3bq2po2==3 & s3bq2po3==3)
/*Coded as 'unspecified number of doses' if response is 'do not know'
Coded As "no dose" if dose was 'NOT GIVEN'/'NOT APPLICABLE'*/
tab POLIO_DO, miss
*CHECK
*-------------------------------------------------
*DPT_DOSE
gen dptdo=0
tab s3bq2dp1, miss
*CHECK
replace dptdo=dptdo+1 if s3bq2dp1==1
tab s3bq2dp2, miss
*CHECK
replace dptdo=dptdo+1 if s3bq2dp2==1
tab s3bq2dp3, miss
*CHECK
replace dptdo=dptdo+1 if s3bq2dp3==1
gen DPT_DOSE = dptdo
replace DPT_DOSE=9 if (s3bq2dp1==3 & s3bq2dp2==3 & s3bq2dp3==3)
/*Coded as 'unspecified number of doses' if response is 'do not know'
Coded As "no dose" if dose was 'NOT GIVEN'/'NOT APPLICABLE'*/
tab DPT_DOSE, miss
*CHECK
*-------------------------------------------------
*MEASLES
gen MEASLES=0 if s3bq2mea==2|s3bq2mea==4
*coded as "no dose" if dose was not given or was not applicable
replace MEASLES=1 if s3bq2mea==1
replace MEASLES=9 if s3bq2mea==3 
tab MEASLES, miss
*-------------------------------------------------
*VACCINE
tab s3bq1, miss
*CHECK
recode s3bq1 (1=3)(2=4), gen (VACCINE)
replace VACCINE=2 if (BCG==1|POLIO_DO<3|DPT_DOSE<3|MEASLES==1)
replace VACCINE=1 if (BCG==1 & POLIO_DO==3 & DPT_DOSE==3 & MEASLES==1)
tab VACCINE AGEM, miss
*CHECK
*-------------------------------------------------
*WEIGHT
gen WEIGHT =.
*-------------------------------------------------
*HEIGHT
gen HEIGHT=.
*-------------------------------------------------
sort HID INDID
merge HID INDID using 04_AGGDATA\GHA_I
tab _merge
drop _merge
*--------------------------------------
label var COUNTRY "Country code"
label var REGION "Region"
label var PROVINCE "Province"
label var DISTRICT "District"
label var HID "Household unique identification"
label var SURVEYR "Year of survey"
label var RURURB "Area of residence"
label var HHSIZE "Household members"
label var HHSIZE_S "Household members including household help"
label var WTA_HH "Individual weighting coefficient"
label var WTA_POP "Population weighting coefficient"
label var INDID "Individual identification"
label def sex 0"Female" 1"Male"
label val SEX sex
label var SEX "Sex"
label def relation 1"Head" ///
	2"Spouse" ///
	3"Child" ///
	4"Father/Mother" ///
	5"Grandchild" ///
	6"Son/Daughter in law" ///
	7"Other relative" ///
	8"Domestic help/Paying boarder" ///
	9"Non-relative"
label val RELAT relation
label var RELAT "Relationship to household head"
label def yn 1"Yes"0"No"
label val HEAD yn
label var HEAD "Household head"
label def mstatus 1"Never married" ///
	2"Married monogamous" ///
	3"Married polygamous" ///
	4"Common law,Living together" ///
	5"Divorced/Separated" ///
	6"Widowed"
label val MARSTAT mstatus
label var MARSTAT "Marital status"
label val SP_PRES yn
label var SP_PRES "Spouse present"
label var AGEY "Age in completed years"
label var ETHNICITY "Ethnicity"
label var LANGUAGE "Language"
label var RELIGION "Religion"
label def litstat 1"Can read or write" ///
	2"Cannot read or write" ///
	3"Cannot be determined"
label val LITERACY litstat
label var LITERACY "Literacy status"
label val EVERATTD yn
label var EVERATTD "Ever attended school"
label val ATSCHOOL yn
label var ATSCHOOL "Current school enrollment"
label def edlev 0"No education" ///
	1"Pre-school/ primary, not completed" ///
	2"Completed primary, but less than completed lower secondary" ///
	3"Completed lower secondary but less than completed upper secondary" ///
	4"Completed upper secondary" ///
	5"Post-secondary technical" ///
	6"University and higher" ///
	7"Formal adult education/litracy program" ///
	9"Other"
label val EDLEVEL_AR edlev
label var EDLEVEL_AR "Highest level of education completed"
label var EDYEARS "Years of education"
label var EDYEARS_AT "Years of education for currently enrolled"
label def schltyp 1"Public" ///
	2"Private" ///
	9"Other"
label val SCHLTYP schltyp
label var SCHLTYP "Type of school attending"
label var MORB_TR "Time reference for variable MORBID (weeks)"
label val MORBID yn
label var MORBID "Morbidity last MORB_TR(weeks)"
label val RTREATM yn
label var RTREATM "Sought medical attention"
label def hlthfac 1"Hospital" ///
	2"Clinics" ///
	3"Dispensary, health center, health post" ///
	4"Outreach" ///
	5"Pharmacy" ///
	6"Traditional healer" ///
	9"Other"
label val HLTHFAC hlthfac
label var HLTHFAC "Health provider visited"
label def owhprovd 1"Public" ///
	2"Private-modern medicine" ///
	3"Private-Traditional healer" ///
	4"Missionary/NGO" ///
	9"Other"
label val OWHPROVD owhprovd
label var OWHPROVD "Ownership of health provider visited"
label var AGEM "Age of child in completed months"
label def whdeliv 1"Trained birth attendant" ///
	2"Traditional birth attendant" ///
	3"Relative/ friend" ///
	9"Other"
label val WHDELIV whdeliv
label var WHDELIV "Who helped assist childbirth"
label def vcard 1"Yes" ///
	2"No, but child vaccinated" ///
	3"No, child never vaccinated" ///
	9"Other"
label val VCARD vcard
label var VCARD "Does the child have a Vaccine Card"
label def bcg 1"Yes" ///
	0"No" ///
	3"No, child never vaccinated" ///
	9"Dont know"
label val BCG bcg
label var BCG "Child immunized against BCG"
label def polio 0"No dose" ///
	1"One dose" ///
	2"Two doses" ///
	3"Three doses" ///
	4"More than three doses" ///
	9"Unspecified number of doses"
label val POLIO_DO polio
label var POLIO_DO "Number of doses of Polio received"
label def dpt_dose 0"No dose" ///
	1"One dose" ///
	2"Two doses" ///
	3"Three doses" ///
	4"More than three doses" ///
	9"Unspecified number of doses"
label val DPT_DOSE dpt_dose
label var DPT_DOSE "Number of doses of DPT received"
label def measles  1"Yes" ///
	0"No" ///
	9"Dont know"
label val MEASLES measles 
label var MEASLES "Child immunized against Measles"
label def vaccine  1"Fully immunized" ///
	2"Partially immunized" ///
	3"Immunized but no information on completeness" ///
	4"Not immunized"
label val VACCINE vaccine
label var VACCINE "Immunization status of child"
label var WEIGHT "Weight of the child (Kg)"
label var HEIGHT "Height of the child (cms)"
*--------------------------------------------------
order COUNTRY REGION PROVINCE DISTRICT HID SURVEYR ///
	RURURB HHSIZE HHSIZE_S WTA_HH WTA_POP INDID SEX RELAT HEAD ///
	MARSTAT SP_PRES AGEY ETHNICITY LANGUAGE RELIGION ///
	LITERACY EVERATTD ATSCHOOL EDLEVEL_AR EDYEARS EDYEARS_AT ///
	SCHLTYP MORB_TR MORBID RTREATM HLTHFAC OWHPROVD AGEM WHDELIV ///
	VCARD BCG POLIO_DO DPT_DOSE MEASLES VACCINE WEIGHT HEIGHT
	
keep COUNTRY REGION PROVINCE DISTRICT HID SURVEYR ///
	RURURB HHSIZE HHSIZE_S WTA_HH WTA_POP INDID SEX RELAT HEAD ///
	MARSTAT SP_PRES AGEY ETHNICITY LANGUAGE RELIGION ///
	LITERACY EVERATTD ATSCHOOL EDLEVEL_AR EDYEARS EDYEARS_AT ///
	SCHLTYP MORB_TR MORBID RTREATM HLTHFAC OWHPROVD AGEM WHDELIV ///
	VCARD BCG POLIO_DO DPT_DOSE MEASLES VACCINE WEIGHT HEIGHT
*-------------------------------------------------
sort HID INDID
count
*number of observations 26,411
save 04_AGGDATA\GHA_1998_I, replace
erase 04_AGGDATA\GHA_I.dta
